@@ -6,8 +6,8 @@ from subprocess import PIPE
 import argparse
 import datetime
 import os
+import pipes
 import re
-import shlex
 import sys
 import subprocess
 import yaml
@@ -39,10 +39,10 @@ def get_grep_cmds(config):
     cmds = {}
     base_cmd = 'grep -RE --exclude "luci.yml" '
     for exclude in config['exclude']:
-        base_cmd += '--exclude-dir ' + shlex.quote(exclude) + ' '
+        base_cmd += '--exclude-dir ' + pipes.quote(exclude) + ' '
 
     for sensitive in config['sensitive']:
-        cmds[sensitive] = base_cmd + shlex.quote(sensitive) + ' `pwd`'
+        cmds[sensitive] = base_cmd + pipes.quote(sensitive) + ' `pwd`'
 
     return cmds
 
@@ -52,7 +52,23 @@ def get_git_toplevel():
     Returns: String
 
     '''
-    return subprocess.getoutput('git rev-parse --show-toplevel')
+    _, output = getstatusoutput('git rev-parse --show-toplevel')
+    return output.rstrip()
+
+def getstatusoutput(cmd):
+    '''Get the status and output from the execution of a command in a shell.
+
+    Returns: (Integer, String)
+
+    '''
+    import subprocess
+    pipe = subprocess.Popen(cmd, shell=True, universal_newlines=True,
+            stdout=subprocess.PIPE, stderr=subprocess.STDOUT)
+    output = str.join('', pipe.stdout.readlines())
+    status = pipe.wait()
+    if status is None:
+        status = 0
+    return status, output
 
 def init():
     '''If run within a git repository, add luci.yml to .gitignore, and add the
@@ -78,7 +94,7 @@ def init():
         files = ['pre-commit', 'post-commit', 'post-merge']
         for f in files:
             backup = 'cp' + hooks + f + hooks + f + '.bak.' + stamp
-            status, _ = subprocess.getstatusoutput(backup)
+            status, _ = getstatusoutput(backup)
             if status == 0:
                 print("Moving" + hooks + f + ' to' + hooks + f +'.bak.' +
                       stamp + "...")
@@ -101,7 +117,7 @@ def is_git_repository():
     Returns: True or False
 
     '''
-    status, _ = subprocess.getstatusoutput('git status')
+    status, _ = getstatusoutput('git status')
     return status == 0
 
 def replace_data(config, find_key, replace_key):
@@ -164,7 +180,7 @@ def sensitive_data_is_present(config):
     '''
     cmds = get_grep_cmds(config)
     for key in cmds:
-        status, _ = subprocess.getstatusoutput(cmds[key])
+        status, _ = getstatusoutput(cmds[key])
         # grep returns 0 if there's a match
         if status == 0:
             return True
@@ -191,7 +207,7 @@ def update_replacements(config):
 
         with grep.stdout as output:
             for line in output:
-                line = str(line, 'UTF-8')
+                line = line.decode('utf-8')
                 path, original = line.rstrip().split(':', 1)
                 scrubbed = re.sub(key, '', original)
                 replacements.append({'path': path, 'original': original,
@@ -243,7 +259,7 @@ def main():
     for a in arguments:
         group.add_argument(a['s'], a['o'], help=a['h'], const=True, nargs='?')
 
-    group.add_argument('-v', '--version', action='version', version='0.2')
+    group.add_argument('-v', '--version', action='version', version='0.3')
 
     args = parser.parse_args()
 
